<?php

namespace App\Http\Controllers\Jdt;

use App\Jocdetrons;
use App\Casa;
use App\Map;
use App\Turn;
use App\TurnMapArmy;
use App\TurnMapOrder;
use App\TurnUser;
use App\HouseCard;
use App\PowerToken;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class JocdetronsController extends Controller
{
    function __construct(){
        $this->middleware('auth',['except'=>'index']);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $jdts = Jocdetrons::MyGames()->get();
        $opengames = Jocdetrons::Opened()->get();
        $games = $opengames->diff($jdts);
        return view('jdt.index',compact('games','jdts'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
       return view('jdt.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name'=>'required',
            ]);

        $jdt = Jocdetrons::create([
            'name' => $request->get('name'),
            'open' => ($request->get('open')!=null)?$request->get('open'):'0',
            'coperative' => ($request->get('coperative')!=null)?$request->get('coperative'):'0',
            'houseassign' => ($request->get('houseassign')!=null)?$request->get('houseassign'):'0',
            'turn' => ($request->get('turn')!=null)?$request->get('turn'):'24:00',
            'gamekind' => ($request->get('gamekind')!=null)?$request->get('gamekind'):'1',
            'invitecode' => $request->get('invitecode'),
            'user_id' => auth()->id()    
        ]);
        $jdt->player()->syncWithoutDetaching(auth()->id());

        return redirect()->route('jdt.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Jocdetrons  $jocdetrons
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $jocdetrons = Jocdetrons::with(['user','player'])->FindorFail($id);
        if($jocdetrons->started){
            return redirect()->route('jdt.turn', [$jocdetrons, $jocdetrons->gameturn->last()]);
        }else{
            return view('jdt.show',compact('jocdetrons'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Jocdetrons  $jocdetrons
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $jocdetrons = Jocdetrons::FindorFail($id);
        $this->authorize($jocdetrons);
        $cases = Casa::all();
        return view('jdt.edit',compact('jocdetrons','cases'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Jocdetrons  $jocdetrons
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $jocdetrons = Jocdetrons::FindorFail($id);
        $this->authorize($jocdetrons);
        $request['open'] = ($request->get('open')!=null)?$request->get('open'):'0';
        $request['coperative'] = ($request->get('coperative')!=null)?$request->get('coperative'):'0';
        $request['houseassign'] = ($request->get('houseassign')!=null)?$request->get('houseassign'):'0';
        $jocdetrons->update($request->all());
        return redirect()->route('jdt.edit', $jocdetrons)->with('info', 'Juego actualizado correctamente');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Jocdetrons  $jocdetrons
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $jocdetrons = Jocdetrons::FindorFail($id);
        $this->authorize($jocdetrons);
        $jocdetrons->delete();
        return back()->with('info',trans('jdt.correcterase'));
    }

    public function inscription(Request $request, $id){
        $jocdetrons = Jocdetrons::FindorFail($id);
        if($request->get('invitecode')==$jocdetrons->invitecode){
            if($jocdetrons->player->count()<6){
                $jocdetrons->player()->syncWithoutDetaching(auth()->id());
                return back()->with('info',trans('jdt.correctinscription'));
            }else{
                return back()->with('error',trans('jdt.completegame'));
            }
        }
        else{
            return back()->with('error',trans('jdt.inviterror'));
        }
    }

    public function houseassign(Request $request, $id){
        $this->validate($request, [
            'house.*' => 'distinct'
            ]);
        $jocdetrons = Jocdetrons::FindorFail($id);
        $players = $request->get('player');
        $houses = $request->get('house');
        for($i = 0; $i < count($players); $i++){
            $jocdetrons->player()->updateExistingPivot($players[$i],['casa_id'=>$houses[$i]]);
        }
        return back()->with('info',trans('jdt.correcthouse'));
    }

    public function startgame($id){
        $jocdetrons=Jocdetrons::FindorFail($id);
        if($jocdetrons->player->count()==6){
            $turn = new Turn;
            $turn->jocdetrons_id = $jocdetrons->id;
            $turn->number = 1;
            $turn->phase = 7;
            $westeroscard = collect([1,2,3,4,5,6,7,8,9,10]);
            $westeros = $westeroscard->shuffle();
            $turn->westeros1 = $westeros;
            $westeroscard = collect([11,12,13,14,15,16,17,18,19,20]);
            $westeros = $westeroscard->shuffle();
            $turn->westeros2 = $westeros;
            $westeroscard = collect([21,22,23,24,25,26,27,28,29,30]);
            $westeros = $westeroscard->shuffle();
            $turn->westeros3 = $westeros;
            $turn->save();

            foreach($jocdetrons->player as $player){
                $turnuser = new TurnUser;
                $turnuser->user_id = $player->id;
                $turnuser->turn_id = $turn->id;
                $turnuser->house_id = $player->pivot->casa_id;
                switch($player->pivot->casa_id){
                    case 1:
                        $turnuser->supply = 1;
                        $turnuser->oThrone = 5;
                        $turnuser->oSword = 2;
                        $turnuser->oCrow = 3;
                        $turnuser->save();
                        foreach(HouseCard::where('casa_id','1')->get() as $housecard){
                            $turnuser->housecard()->syncWithoutDetaching($housecard);   
                        }
                        
                        //Tropa a Invernalia
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 1;
                        $turnarmy->territory_id = 4;
                        $turnarmy->save();
                        //Cavaller a Invernalia
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 2;
                        $turnarmy->territory_id = 4;
                        $turnarmy->save();
                        //Tropa a Puerto Blanco
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 1;
                        $turnarmy->territory_id = 7;
                        $turnarmy->save();
                        //Flota a Mar de los escalofríos
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 3;
                        $turnarmy->territory_id = 3;
                        $turnarmy->save();

                        $token = new PowerToken;
                        $token->turn_id = $turn->id;
                        $token->turnuser_id = $turnuser->id;
                        $token->map_id = 4;
                        $token->save();
                        break;
                    case 2:
                        $turnuser->supply = 2;
                        $turnuser->oThrone = 1;
                        $turnuser->oSword = 6;
                        $turnuser->oCrow = 4;
                        $turnuser->save();
                        foreach(HouseCard::where('casa_id','2')->get() as $housecard){
                            $turnuser->housecard()->syncWithoutDetaching($housecard);   
                        }
                        //Infante a Rocadragon
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 1;
                        $turnarmy->territory_id = 27;
                        $turnarmy->save();
                        //Infante a Rocadragon
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 1;
                        $turnarmy->territory_id = 27;
                        $turnarmy->save();
                        //Infante a Bosc Reial
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 1;
                        $turnarmy->territory_id = 36;
                        $turnarmy->save();
                        //Flota a Bahía dels Naufragis
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 3;
                        $turnarmy->territory_id = 26;
                        $turnarmy->save();
                        //Flota a Bahía dels Naufragis
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 3;
                        $turnarmy->territory_id = 26;
                        $turnarmy->save();

                        $token = new PowerToken;
                        $token->turn_id = $turn->id;
                        $token->turnuser_id = $turnuser->id;
                        $token->map_id = 27;
                        $token->save();
                        break;
                    case 3:
                        $turnuser->supply = 2;
                        $turnuser->oThrone = 6;
                        $turnuser->oSword = 4;
                        $turnuser->oCrow = 1;
                        $turnuser->save();
                        foreach(HouseCard::where('casa_id','3')->get() as $housecard){
                            $turnuser->housecard()->syncWithoutDetaching($housecard);   
                        }
                        //Infante a Lanisport
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 1;
                        $turnarmy->territory_id = 21;
                        $turnarmy->save();
                        //Cavaller a Lanisport
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 2;
                        $turnarmy->territory_id = 21;
                        $turnarmy->save();
                        //Infante a Sept de Piedra
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 1;
                        $turnarmy->territory_id = 28;
                        $turnarmy->save();
                        //Flota a Sonido Dorado
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 3;
                        $turnarmy->territory_id = 20;
                        $turnarmy->save();

                        $token = new PowerToken;
                        $token->turn_id = $turn->id;
                        $token->turnuser_id = $turnuser->id;
                        $token->map_id = 21;
                        $token->save();
                        break;
                    case 4:
                        $turnuser->supply = 2;
                        $turnuser->oThrone = 4;
                        $turnuser->oSword = 1;
                        $turnuser->oCrow = 6;
                        $turnuser->save();
                        foreach(HouseCard::where('casa_id','4')->get() as $housecard){
                            $turnuser->housecard()->syncWithoutDetaching($housecard);   
                        }
                        //Infante a Pyke
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 1;
                        $turnarmy->territory_id = 15;
                        $turnarmy->save();
                        //Infante a Pyke
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 1;
                        $turnarmy->territory_id = 15;
                        $turnarmy->save();
                        //Infante a Atalaya de Aguas Grises
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 1;
                        $turnarmy->territory_id = 11;
                        $turnarmy->save();
                        //Vaixell a Bahía del Ferro
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 3;
                        $turnarmy->territory_id = 14;
                        $turnarmy->save();
                        //Vaixell a Bahía del Ferro
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 3;
                        $turnarmy->territory_id = 14;
                        $turnarmy->save();

                        $token = new PowerToken;
                        $token->turn_id = $turn->id;
                        $token->turnuser_id = $turnuser->id;
                        $token->map_id = 15;
                        $token->save();
                        break;
                    case 5:
                        $turnuser->supply = 2;
                        $turnuser->oThrone = 2;
                        $turnuser->oSword = 3;
                        $turnuser->oCrow = 5;
                        $turnuser->save();
                        foreach(HouseCard::where('casa_id','5')->get() as $housecard){
                            $turnuser->housecard()->syncWithoutDetaching($housecard);   
                        }
                        //Infante a Altojardin
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 1;
                        $turnarmy->territory_id = 34;
                        $turnarmy->save();
                        //Cavaller a Altojardin
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 2;
                        $turnarmy->territory_id = 34;
                        $turnarmy->save();
                        //Infante a Marques de Dorne;
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 1;
                        $turnarmy->territory_id = 38;
                        $turnarmy->save();
                        //Vaixell a Estret de Redwyne
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 3;
                        $turnarmy->territory_id = 37;
                        $turnarmy->save();

                        $token = new PowerToken;
                        $token->turn_id = $turn->id;
                        $token->turnuser_id = $turnuser->id;
                        $token->map_id = 34;
                        $token->save();
                        break;
                    case 6:
                        $turnuser->supply = 2;
                        $turnuser->oThrone = 3;
                        $turnuser->oSword = 5;
                        $turnuser->oCrow = 2;
                        $turnuser->save();
                        foreach(HouseCard::where('casa_id','6')->get() as $housecard){
                            $turnuser->housecard()->syncWithoutDetaching($housecard);   
                        }
                        //Infante a Lanza del Sol
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 1;
                        $turnarmy->territory_id = 50;
                        $turnarmy->save();
                        //Cavaller a Llança del Sol
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 2;
                        $turnarmy->territory_id = 50;
                        $turnarmy->save();
                        //Infante a Acantilats de Sal
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 1;
                        $turnarmy->territory_id = 49;
                        $turnarmy->save();
                        //Vaixell a Mar del Estiu
                        $turnarmy = new TurnMapArmy;
                        $turnarmy->turn_id = $turn->id;
                        $turnarmy->turnuser_id = $turnuser->id;
                        $turnarmy->army_id = 3;
                        $turnarmy->territory_id = 41;
                        $turnarmy->save();

                        $token = new PowerToken;
                        $token->turn_id = $turn->id;
                        $token->turnuser_id = $turnuser->id;
                        $token->map_id = 50;
                        $token->save();
                        break;
                }
            }
            $jocdetrons->update(['started'=>1]);  
            return redirect()->route('jdt.turn', [$jocdetrons, $turn]);
        } else {
            return back()->with('error',trans('no es pot iniciar la partida per què no hi ha suficients jugadors o no estan totes les cases assignades'));
        }
    }

}
