<?php

namespace App\Http\Controllers;

use App\Message;
use Illuminate\Http\Request;
use App\User;
use App\Http\Requests\MessageRequest;
use Carbon\Carbon;

class MessageController extends Controller
{
    function __construct(){
        $this->middleware('auth');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $messages = Message::messaged()->get();
        
        return view('message.index',compact('messages'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    
     public function create($id)
    {
        $user = User::findorFail($id);
        return view('message.create',compact('user'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(MessageRequest $request)
    {
        if(auth()->user()->id == $request->get('sender_id')){
            Message::create([
                'subject' => $request->get('subject'),
                'message' => $request->get('message'),
                'receiver_id' => $request->get('receiver_id'),
                'sender_id' => $request->get('sender_id'),    
            ]);
            
            return redirect()->route('message.index');
        }
        return back()->with('info','No esta autorizado a enviar este mensaje');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Message  $message
     * @return \Illuminate\Http\Response
     */
    public function show(Message $message)
    {
        $this->authorize($message);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Message  $message
     * @return \Illuminate\Http\Response
     */
    public function edit(Message $message)
    {
        $this->authorize($message);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Message  $message
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Message $message)
    {
        $this->authorize($message);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Message  $message
     * @return \Illuminate\Http\Response
     */
    public function destroy(Message $message)
    {
        $carbon = new Carbon();
        if($message->deleted_sender == null && $message->deleted_receiver == null){
            if($message->sender_id == auth()->user()->id){
                $message->deleted_sender = $carbon;
                $message->save();
            }else{
                $message->deleted_receiver = $carbon;
                $message->save();
            }
        }else{
            $message->delete();
        }

        return redirect()->route('message.index')->with('info','Mensaje borrado correctamente');
    }
}
