<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Carbon\Carbon;

class Post extends Model
{
    protected $fillable = [
        'title',
        'body',
        'excerpt',
        'published_at',
        'category_id',
        'user_id',
    ];

    protected $dates = ['published_at'];

    protected static function boot(){
        parent::boot();
        static::deleting(function($post){
            $post->photos->each->delete();
        });
    }

    public function category($value=''){
        return $this->belongsTo(Category::class);
    }
    public function photos(){
        return $this->hasMany(Photo::class);
    }
    public function user(){
        return $this->belongsTo(User::class);
    }
    public function scopePublished($query){
        $query->with(['user','category','photos'])
            ->whereNotNull('published_at')
            ->where('published_at','<=', Carbon::now())
            ->where('category_id','!=','2')
            ->latest('published_at');
    }
    public function scopeAllowed($query){
        if( auth()->user()->hasRoles(['admin']) ){
            return $query;
        }
        
        return $query->where('user_id', auth()->id());
    }
    public function scopeRules($query){
        $query->whereNotNull('published_at')
        ->where('published_at','<=', Carbon::now())
        ->where('category_id','2')
        ->oldest('published_at');
    }
    public function setPublishedAtAttribute($published_at){
        $this->attributes['published_at'] = $published_at ? Carbon::createFromFormat('d/m/Y',$published_at) : null;
    }
    public function setCategoryIdAttribute($category){
        $this->attributes['category_id'] = Category::find($category)? $category : Category::create(['name'=>$category])->id;
    }
}
