<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Collection;

class Turn extends Model
{
    protected $fillable = ['jocdetrons_id','number','phase','player_id'];
    
    public function Joc(){
        return $this->belongsTo(Jocdetrons::class,'jocdetrons_id');
    }
    public function TurnUser(){
        return $this->hasMany(TurnUser::class);
    }
    public function WesterosCard(){
        return $this->belongsToMany(WesterosCard::class,'turns_westeros_cards','turn_id','westeroscard_id')->withPivot('finished');
    }
    public function scopeTurn($query, $id){
        $query->with(['turnuser'])
            ->where('id', $id);
    }
    public function TotalTerritories(){
        $result=0;
        foreach($this->TurnUser as $Userturn){
            $result += $Userturn->army->unique('territory_id')->count();
        }
        return $result;
    }
    public function TotalOrders(){
        $result=0;
        foreach($this->TurnUser as $Userturn){
            $result += $Userturn->orders->count();
        }
        return $result;
    }
    public function OrdersToRaid(){
        $result = new Collection;
        foreach($this->TurnUser as $Userturn){
            foreach($Userturn->orders->whereIn('order_id',['4','5','6','10','11','12','13','14','15']) as $order){
                $result->push($order->territory_id);
            } 
        }
        return $result;
    }
    public function TurnOrders(){
        $result = new Collection;
        foreach($this->TurnUser as $Userturn){
            foreach($Userturn->orders as $order){
                $result->push($order);
            } 
        }
        return $result;
    }
    public function OcupedTerritories(){
        $result = new Collection;
        foreach($this->TurnUser as $Userturn){
            foreach($Userturn->army as $army){
                $result->push($army);
            } 
        }
        return $result;
    }
    public function Combats(){
        $result = new Collection;
        foreach($this->TurnUser as $Userturn){
            foreach($Userturn->attack as $attack){
                $result->push($attack);
            } 
        }
        return $result;
    }
    public function PowerTokens(){
        $result = new Collection;
        foreach($this->TurnUser as $Userturn){
            foreach($Userturn->PowerToken as $token){
                $result->push($token);
            }
        }
        return $result;
    }
    public function westerosfinish(){
        foreach($this->TurnUser as $userturn){
            if(!$userturn->westeros){
                return false;
            }
        }
        return true;
    }
    public function ThroneOrder($id = 0){
        if($id == 0){
            $index = 0;
        } else {
            $index = $this->TurnUser()->where('user_id',$id)->first()->oThrone;
        }
        if($index==6){
            $index = 1;
        }else{
            $index++;
        }
        $oThrone = collect();
        $oThrone->push($this->TurnUser->firstWhere('oThrone',$index));
        while($oThrone->count()<6){
            if($index==6){
                $index=0;
            }
            $oThrone->push($this->TurnUser->firstWhere('oThrone',++$index));
        }
        return $oThrone;
    }
    public function StartWesteros($westerosdeck, $shuffle = false){
        $westeros = collect(explode(",", substr($westerosdeck, 1, -1)));
        if($shuffle){
            $westeros->shuffle();
        }
        $westeros1 = $westeros->splice(1);
        $WesterosCard = WesterosCard::FindorFail($westeros->first());
        $this->WesterosCard()->syncWithoutDetaching($WesterosCard);
        $westeros->prepend($westeros1);
        return str_replace('"','',$westeros->flatten());
    }
    public function scopePrevious($query, $jocdetrons_id){
        $query->where('jocdetrons_id',$jocdetrons_id)
            ->where('number',($this->number-1));
    }
    public function hasWinner(){
        return false;
    }
}
