<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;


class TurnUser extends Model
{
    use SoftDeletes;

    protected $fillable = ['user_id','turn_id','house_id','supply','oThrone','oSword','oCrow','victory','ovictory','powertokens','westeros','bThrone','bSword','bCrow'];

    public function turn(){
        return $this->belongsTo(Turn::class);
    }
    public function user(){
        return $this->belongsTo(User::class);
    }
    public function house(){
        return $this->belongsTo(Casa::class);
    }
    public function army(){
        return $this->hasMany(TurnMapArmy::class,'turnuser_id');
    }
    public function orders(){
        return $this->hasMany(TurnMapOrder::class,'turnuser_id');
    }
    public function PowerToken(){
        return $this->hasMany(PowerToken::class,'turnuser_id');
    }
    public function Attack(){
        return $this->hasMany(Combat::class,'attack_id');
    }
    public function Defender(){
        return $this->hasMany(Combat::class,'defender_id');
    }
    public function HouseCard(){
        return $this->belongsToMany(HouseCard::class,'turnuser_housecard','turnuser_id','housecard_id')
            ->WithPivot('used');
    }
    public function scopeAtacant($query){
        $query->join('combats', 'turn_users.id', '=', 'combats.attack_id')
            ->where('combats.finished','0')
            ->with(['house']);
    }
    public function scopeDefensor($query){
        $query->join('combats', 'turn_users.id', '=', 'combats.defender_id')
            ->where('combats.finished','0')
            ->with(['house']);
    }
    public function scopeTorn($query, $id){
        $query->with(['turn','house','army','orders','Housecard'])
            ->where('turn_id', $id);
    }
    public function scopeTotalterritory($query){
        $query->join('turn_map_armies','turn_users.id','=','turn_map_armies.turnuser_id')
            ->select('turn_map_armies.*');
    }
    public function scopeVictoryorder($query){
        $query->orderBy('victory','DESC')
            ->orderBy('supply','DESC')
            ->orderBy('powertokens','DESC')
            ->orderBy('oThrone','ASC');
    }
    public function scopeBthroneorder($query){
        $query->orderBy('bThrone','DESC')
            ->orderBy('oThrone','ASC');
    }
    public function scopeBswordorder($query){
        $query->orderBy('bSword','DESC')
            ->orderBy('oThrone','ASC');
    }
    public function scopeBcroworder($query){
        $query->orderBy('bCrow','DESC')
            ->orderBy('oThrone','ASC');
    }
    public function MaxEspecialOrders(){
        switch($this->oCrow){
            case(1):
            case(2):   
                $maxespecial=3;
                break;
            case(3):
                $maxespecial=2;
                break;
            case(4):
                $maxespecial=1;
                break;
            case(5):
            case(6):
                $maxespecial=0;
                break;
        }
        return $maxespecial;
    }
    public function hasSword(){
        if($this->oSword == 1){
            foreach($this->attack as $attack){
                if($attack->sword==1 && $attack->finished==1){
                    return false;
                }
            }
            foreach($this->defender as $defensa){
                if($defensa->sword==1 && $defensa->finished==1){
                    return false;
                }
            }
            return true;
        }
        return false;
    }
    public function hasRaids(){
        foreach($this->orders as $order){
            if($order->order_id == 10 || $order->order_id == 11 || $order->order_id == 12){
                return true;
            }
        }
        return false;
    }
    public function hasMovements(){
        foreach($this->orders as $order){
            if($order->order_id == 1 || $order->order_id == 2 || $order->order_id == 3){
                return true;
            }
        }
        return false;
    }
    public function hasSuports(){
        foreach($this->orders as $order){
            if($order->order_id == 4 || $order->order_id == 5 || $order->order_id == 6){
                return true;
            }
        }
        return false;
    }
    public function hasCrowns(){
        foreach($this->orders as $order){
            if($order->order_id == 13 || $order->order_id == 14 || $order->order_id == 15){
                return true;
            }
        }
        return false;
    }
    public function strength($territory){
        $strength = 0;
        if($this->orders->whereIn('order_id',['7','8','9'])->where('territory_id',$territory)->first()!=null){
            $strength += $this->orders->whereIn('order_id',['7','8','9'])->where('territory_id',$territory)->first()->strength();
        }
        foreach($this->army->where('territory_id',$territory) as $army){
            if($army->army->retreat!=false){
                $strength += $army->army->strength;
            }
        }
        if($this->hasSuports()){
            $sea = $this->army->firstWhere('territory_id',$territory)->territory->sea;
            foreach($this->army->firstWhere('territory_id',$territory)->territory->neighbors as $neighbor){
                foreach($this->orders->where('territory_id',$neighbor->id) as $order){
                    if(!$sea || ($sea && $order->territory->sea)){
                        if($order->whereIn('order_id',['4','5','6'])){
                            if($order->territory_id != $territory){
                                $strength += $order->strength();
                                foreach($this->army->where('territory_id',$order->territory_id) as $suportarmy){
                                    if($suportarmy->army->retreat == false){
                                        $strength += $suportarmy->army->strength;
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
        return $strength;
    }
    public function MapControlled(){
        $mapcollection = collect();
        foreach($this->PowerToken->where('turn_id',$this->turn_id) as $PowerToken){
            if($PowerToken->territory->castles > 0){
                $mapcollection->push($PowerToken->map_id);
            }
        }
        foreach($this->army->where('turn_id',$this->turn_id) as $army){
            if($army->territory->castles > 0){
                $mapcollection->push($army->territory_id);
            }
        }
        $result = $mapcollection->unique();
        return $result;
    }
    public function victoryPoints(){
        $mapcollection = collect();
        foreach($this->PowerToken->where('turn_id',$this->turn_id) as $PowerToken){
            if($PowerToken->territory->castles > 0){
                $mapcollection->push($PowerToken->map_id);
            }
        }
        foreach($this->army->where('turn_id',$this->turn_id) as $army){
            if($army->territory->castles > 0){
                $mapcollection->push($army->territory_id);
            }
        }
        $result = $mapcollection->unique();
        $this->update(['victory'=>$result->count()]);
        return $result->count();
    }
    public function Supply(){
        $mapcollection = collect();
        foreach($this->PowerToken->where('turn_id',$this->turn_id) as $PowerToken){
            if($PowerToken->territory->supply > 0){
                $mapcollection->push([
                    'id'=>$PowerToken->map_id,
                    'supply'=> $PowerToken->territory->supply
                ]);
            }
        }
        foreach($this->army->where('turn_id',$this->turn_id) as $army){
            if($army->territory->supply > 0){
                $mapcollection->push([
                    'id'=>$army->map_id,
                    'supply'=> $army->territory->supply
                ]);
            }
        }
        $finishmap = $mapcollection->unique();
        $result = 0;
        foreach($finishmap as $map){
            $result = $result + $map['supply'];
        }
        return $result;
    }
    public function Power(){
        $mapcollection = collect();
        foreach($this->PowerToken->where('turn_id',$this->turn_id) as $PowerToken){
            if($PowerToken->territory->crowns > 0){
                $mapcollection->push([
                    'id'=>$PowerToken->map_id,
                    'crowns'=> $PowerToken->territory->crowns
                ]);
            }
        }
        foreach($this->army->where('turn_id',$this->turn_id) as $army){
            if($army->territory->crowns > 0){
                $mapcollection->push([
                    'id'=>$army->map_id,
                    'crowns'=> $army->territory->crowns
                ]);
            }
        }
        $finishmap = $mapcollection->unique();
        $result = $this->powertokens;
        foreach($finishmap as $map){
            $result = $result + $map['crowns'];
        }
        return $result;
    }
    public function maxarmy(){
        $result=2;
        switch($this->supply){
            case(0):
                $result=2;
                break;
            case(1):
                $result=3;
                break;
            case(2):
                $result=3;
                break;
            case(3):
                $result=3;
                break;
            case(4):
                $result=3;
                break;
            case(5):
                $result=4;
                break;
            case(6):
                $result=4;
                break;
        }
        return $result;
    }
}
