<?php

namespace App;

use App\Role;
use Illuminate\Notifications\Notifiable;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Database\Eloquent\SoftDeletes;
use Carbon\Carbon;

class User extends Authenticatable
{
    use Notifiable;
    use SoftDeletes;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name', 'email', 'password','alias','role_id','surname','birthday','deleted_at','lang','description'
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    protected $dates = ['deleted_at','birthday'];

    public function role(){
        return $this->belongsTo(Role::class);
    }
    public function player(){
        return $this->belongsToMany(Jocdetrons::class,'jocdetrons_user','user_id','jocdetrons_id');
    }
    public function casa(){
        return $this->belongsToMany(casa::class,'jocdetrons_user','user_id','casa_id');
    }
    public function turn(){
        return $this->hasMany(TurnUser::class);
    }
    public function hasRoles(array $roles){
        foreach($roles as $role){
            if($this->role->name === $role){
                return true;
            }
        }
        return false;
    }
    public function setPasswordAttribute($password) 
    { 
        return $this->attributes['password'] = bcrypt($password); 
    }
    public function setBirthdayAttribute($birthday){
        $this->attributes['birthday'] = Carbon::createFromFormat('d/m/Y',$birthday);
    }
    public function scopeAllUser($query){
        return $query->with('role');
    }
}
