@extends('layouts.app')

@section('content')
<div class="container">
    @if(session()->has('info'))
        <div class="alert alert-danger" role="alert">
           {{session('info')}}
        </div>
    @endif
    <div class="row justify-content-center">
        <div class="card">
            <div class="card-header">
                <h3 class="card-title">@lang('post.publishedposts')</h3>
                <button class="btn btn-veenders pull-right" data-toggle="modal" data-target="#exampleModal"><i class="fa fa-plus"></i> @lang('post.create')</button>
            </div>
            <div class="card-body">
                <table id="posts-table" class="table table-bordered table-striped">
                    <thead>
                        <tr>
                            <th>@lang('post.id')</th>
                            <th>@lang('post.title')</th>
                            <th>@lang('post.excerpt')</th>
                            <th>@lang('post.published_at')</th>
                            <th>@lang('post.accions')</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach($posts as $post)
                        <tr>
                            <td>{{ $post->id }}</td>
                            <td>{{ $post->title }}</td>
                            <td>{{ $post->excerpt }}</td>
                            <td>{{ filled($post->published_at) ? $post->published_at->format('d M Y') : trans('post.nopublish') }}</td>
                            <td>
                                <a href="{{ route('blog.show', $post)}}" class="btn btn-sm btn-veenders" target="_blank"><i class="fa fa-eye"></i></a>
                                <a href="{{ route('post.edit', $post)}}" class="btn btn-sm btn-veenders2"><i class="fa fa-pencil"></i></a>
                                <form method="POST" action="{{ route('post.destroy',$post) }}" style="display:inline">
                                    @csrf
                                    @method('DELETE')
                                    <button class="btn btn-sm btn-danger" onclick="return confirm('@lang('post.eraseconfirm')')"><i class="fa fa-trash"></i></button>
                                </form>
                                
                            </td>
                        </tr>
                        @endforeach
                    </tbody>
                    <tfoot>
                        <tr>
                            <th>@lang('post.id')</th>
                            <th>@lang('post.title')</th>
                            <th>@lang('post.excerpt')</th>
                            <th>@lang('post.published_at')</th>
                            <th>@lang('post.accions')</th>
                        </tr>
                    </tfoot>
                </table>
            </div>
        </div>
    </div>
</div>
@endsection

@push('styles')
    <!-- DataTables -->
    <link rel="stylesheet" href="https://cdn.datatables.net/1.10.16/css/jquery.dataTables.min.css">
@endpush
@push('scripts')
<div class="modal" id="exampleModal" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
      <div class="modal-content">
        <form method="POST" action="{{route('post.store')}}">
            @csrf
            <div class="modal-header">
            <h5 class="modal-title" id="exampleModalLabel">@lang('post.create')</h5>
            <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                <span aria-hidden="true" class="secundari">&times;</span>
            </button>
            </div>
            <div class="modal-body">
                <div class="form-group {{ $errors->has('title') ? 'has-error':''}}">
                    <label>@lang('post.title')</label>
                    <input name="title" class="form-control" value="{{old('title')}}" placeholder="@lang('post.inttitle')" required>
                    {!! $errors->first('title','<span class="help-block">:message</span>') !!}
                </div>
            </div>
            <div class="modal-footer">
            <button type="button" class="btn btn-veenders2" data-dismiss="modal">@lang('navigation.close')</button>
            <button type="submit" class="btn btn-veenders">@lang('navigation.accept')</button>
            </div>
        </form>
      </div>
    </div>
  </div>
<script src="https://cdn.datatables.net/1.10.16/js/jquery.dataTables.min.js"></script>
<script>
    $(function () {
        $('#posts-table').DataTable({
        'paging'      : true,
        'lengthChange': false,
        'searching'   : true,
        'ordering'    : true,
        'info'        : true,
        'autoWidth'   : false,
        language: {
            search: "Cercar:",
            processing:     "Processant...",
            lengthMenu:    "Mostrar _MENU_ registres",
            info:           "Mostrant registres del _START_ al _END_ d'un total de _TOTAL_ registres",
            infoEmpty:      "No hi han registres",
            infoFiltered:   "(filtrat d'un total de _MAX_ registres)",
            infoPostFix:    "",
            loadingRecords: "Carregant registres...",
            zeroRecords:    "No s'han trobat registres",
            emptyTable:     "No hi ha informació disponible",
            paginate: {
                first:      "Primera",
                previous:   "Anterior",
                next:       "Següent",
                last:       "Última"
            },
            aria: {
                sortAscending:  ": Activar per ordenar la columna de manera ascendent",
                sortDescending: ": Activar per ordenar la columna de manera descendent"
            }
        },
        "columns": [
            { "width": "5%" },
            { "width": "15%" },
            { "width": "55%" },
            { "width": "10%" },
            { "width": "15%" },
        ]
        })
    })
</script>

@endpush