@extends('layouts.app')

@section('content')
@if(session()->has('info'))
    <div class="alert alert-success" role="alert">
        @lang('post.updateok')
    </div>
@endif
@if($post->photos->count())
    <div class="row fotos">
        <div class="col-md-12">
            <div class="d-flex flex-row">
                @foreach ($post->photos as $photo)
                    <form method="POST" action="{{ route('post.photos.destroy', $photo)}}">
                        @method('delete')
                        @csrf
                        <div class="col-md-12">
                            <button class="btn btn-danger btn-xs" style="position:absolute"><i class="fa fa-remove"></i></button>
                            <img class="img-responsive" src="{{ url($photo->url)}}">
                        </div>
                    </form>
                @endforeach
            </div>
        </div>
    </div>
@endif
<div class="container">
    <div class="row justify-content-center">
        <div class="card">
            <div class="card-header"><h3>@lang('post.create')</h3></div>
            <div class="card-body">
                <form method="POST" action="{{route('post.update', $post)}}">
                    <div class="row">
                        @method('put')
                        @csrf
                        <div class="col-md-8">
                            <h3><small>@lang('post.contentpost')</small></h3>
                            <div class="form-group {{ $errors->has('title') ? 'has-error':''}}">
                                <label>@lang('post.title')</label>
                                <input name="title" class="form-control" value="{{old('title', $post->title)}}" placeholder="@lang('post.inttitle')">
                                {!! $errors->first('title','<span class="help-block">:message</span>') !!}
                            </div>
                            <div class="form-group {{ $errors->has('body') ? 'has-error':''}}">
                                <label>@lang('post.content')</label>
                                <textarea name="body" id="editor" class="form-control" placeholder="@lang('post.intcontent')" rows="10">{{ old('body',$post->body) }}</textarea>
                                {!! $errors->first('body','<span class="help-block">:message</span>') !!}
                            </div>
                        </div>
                        <div class="col-md-4">
                            <h3><small>@lang('post.aditional')</small></h3>
                            <div class="form-group">
                                <label>@lang('post.published_at'):</label>
                                <div class="input-group date">
                                    <div class="input-group-prepend">
                                        <i class="fa fa-calendar input-group-text"></i>
                                    </div>
                                    <input name="published_at" type="text" class="form-control pull-right" value="{{old('published_at',$post->published_at ? $post->published_at->format('d/m/Y'):'')}}" id="published_at">
                                </div>
                            </div>
                            <div class="form-group {{ $errors->has('category_id') ? 'has-error':''}}">
                                <label for="categorias">@lang('post.categories')</label>
                                <select name="category_id" id="category_id" class="form-control select2">
                                    @foreach ($categories as $category)
                                        <option value="{{$category->id}}" {{old('category_id', $post->category_id) == $category->id ? 'selected':''}}>{{$category->name}}</option>
                                    @endforeach
                                </select>
                                {!! $errors->first('category_id','<span class="help-block">:message</span>') !!}
                            </div>
                            <div class="form-group {{ $errors->has('excerpt') ? 'has-error':''}}">
                                <label>@lang('post.excerpt')</label>
                                <textarea name="excerpt" class="form-control" placeholder="@lang('post.intexcerpt')">{{old('excerpt',$post->excerpt)}}</textarea>
                                {!! $errors->first('excerpt','<span class="help-block">:message</span>') !!}
                            </div>
                            <div class="form-group">
                                <div class="dropzone"></div>
                            </div>
                            <div class="form-group">
                                <button type="submit" class="btn btn-veenders btn-block"><i class="fa fa-floppy-o" aria-hidden="true"></i> @lang('post.save')</button>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>
@stop
@push('styles')
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/dropzone/5.2.0/min/dropzone.min.css">
    <link rel="stylesheet" href="/plugins/select2/dist/css/select2.min.css">
@endpush
@push('scripts')
    <script type="text/javascript" src="/plugins/dropzone/dropzone.js"></script>
    <script type="text/javascript" src="/plugins/datepicker/bootstrap-datepicker.js"></script>
    <script type="text/javascript" src="/plugins/datepicker/locales/bootstrap-datepicker.ca.js" charset="UTF-8"></script>
    <script type="text/javascript" src="/plugins/datepicker/locales/bootstrap-datepicker.es.js" charset="UTF-8"></script>
    <script src="/plugins/ckeditor/ckeditor.js"></script>
    <script src="/plugins/select2/dist/js/select2.full.min.js"></script>
    <script>
        $('#published_at').datepicker({
            autoclose:true,
            weekStart: 1,
            language: '<?php echo App::getLocale();?>',
        });
        CKEDITOR.replace('editor');
        $('.select2').select2({
            tags:true
        });
        var myDropzone = new Dropzone('.dropzone',{
            url:'/post/posts/{{ $post->id }}/photos',
            paramName: 'photo',
            acceptedFiles: 'image/*',
            maxFilesize: 2,
            headers: {
                'X-CSRF-TOKEN' : '{{ csrf_token() }}'
            },
            dictDefaultMessage: '@lang('post.upimages')'
        });
        myDropzone.on('error', function(file,res){
            var msg = res.errors.photo[0];
            $('.dz-error-message:last > span').text(msg);
        })
        Dropzone.autoDiscover=false;
    </script>
@endpush