@extends('layouts.app')

@section('content')

<div class="container">
    <div class="row justify-content-center">
        <div class="card">
            <h3 class="card-header">@lang('user.userlist')</h3>
            <div class="card-body">
                <table id="users-table" class="table table-bordered table-hover table-striped">
                    <thead>
                        <tr>
                            <th>@lang('user.alias')</th>
                            <th>@lang('user.name')</th>
                            <th>@lang('user.surname')</th>
                            <th>@lang('user.role')</th>
                            @if (auth()->user()->hasRoles(['admin']))
                                <th>@lang('user.email')</th>
                                <th>@lang('user.birthday')</th>
                            @endif
                            <th>@lang('user.actions')</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach($users as $user)
                            <tr>
                                <td>{{ $user->alias}}</td>
                                <td>{{ $user->name}}</td>
                                <td>{{ $user->surname}}</td>
                                <td>{{ $user->role->displayName}}</td>
                                @if (auth()->user()->hasRoles(['admin']))
                                    <td>{{ $user->email}}</td>
                                    <td>{{ $user->birthday->format('d M Y')}}</td>
                                @endif
                                <td><a href="{{ route('user.show',$user->id) }}" class="btn btn-veenders btn-sm"><i class="fa fa-eye" aria-hidden="true"></i></a>
                                    @can('edit', $user)
                                        <a href="{{ route('user.edit',$user->id) }}" class="btn btn-veenders2 btn-sm"><i class="fa fa-pencil" aria-hidden="true"></i></a>
                                        <form method="POST" action="{{ route('user.destroy',$user) }}" style="display:inline">
                                            @csrf
                                            @method('DELETE')
                                            <button class="btn btn-sm btn-danger" onclick="return confirm('@lang('user.eraseconfirm')')"><i class="fa fa-trash"></i></button>
                                        </form>
                                    @endcan
                                </td>
                            </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>

@endsection

@push('styles')
    <!-- DataTables -->
    <link rel="stylesheet" href="https://cdn.datatables.net/1.10.16/css/jquery.dataTables.min.css">
@endpush
@push('scripts')
    
    <script src="https://cdn.datatables.net/1.10.16/js/jquery.dataTables.min.js"></script>
    <script>
        $(function () {
            $('#users-table').DataTable({
            'paging'      : true,
            'lengthChange': false,
            'searching'   : true,
            'ordering'    : true,
            'info'        : true,
            'autoWidth'   : false,
            language: {
                search: "Cercar:",
                processing:     "Processant...",
                lengthMenu:    "Mostrar _MENU_ registres",
                info:           "Mostrant registres del _START_ al _END_ d'un total de _TOTAL_ registres",
                infoEmpty:      "No hi han registres",
                infoFiltered:   "(filtrat d'un total de _MAX_ registres)",
                infoPostFix:    "",
                loadingRecords: "Carregant registres...",
                zeroRecords:    "No s'han trobat registres",
                emptyTable:     "No hi ha informació disponible",
                paginate: {
                    first:      "Primera",
                    previous:   "Anterior",
                    next:       "Següent",
                    last:       "Última"
                },
                aria: {
                    sortAscending:  ": Activar per ordenar la columna de manera ascendent",
                    sortDescending: ": Activar per ordenar la columna de manera descendent"
                }
            }
            })
        })
    </script>

@endpush