<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
Route::group(['middleware' => ['lang']], function () {
    
    //Rutes públiques
    Route::get('/', 'PublicController@welcome');
    Route::get('/blog','PublicController@index')->name('blog.index');
    Route::get('/blog/{post}', 'PublicController@show')->name('blog.show');
    Route::get('/rules','PublicController@rules')->name('rules');

    //login i registre d'usuaris.
    Auth::routes();

    //Rutes després de Login
    Route::get('/home', 'HomeController@index')->name('home');
    

    //Rutes Gestió d'usuaris
    Route::resource('user','UserController');

    //Rutes Gestió de Missatges
    Route::get('/message/create/{id}','MessageController@create')->name('message.send');
    Route::resource('message','MessageController');

    //Rutes Gestió de Posts
    Route::group([
            'prefix' => 'post',
            'namespace' => 'Post',
            ],
        function(){
            Route::get('/','PostController@index')->name('post.index');
            Route::post('posts', 'PostController@store')->name('post.store');
            Route::get('posts/{post}', 'PostController@edit')->name('post.edit');
            Route::put('posts/{post}', 'PostController@update')->name('post.update');
            Route::delete('posts/{post}', 'PostController@destroy')->name('post.destroy');

            Route::post('posts/{post}/photos', 'PhotoController@store')->name('post.photos.store');
            Route::delete('photos/{photo}', 'PhotoController@destroy')->name('post.photos.destroy');

    });

    Route::group([
            'namespace' => 'Jdt',
        ],
        function(){
            Route::get('/jdt/{jdt}/startgame','JocdetronsController@startgame')->name('jdt.start');
            Route::post('/jdt/inscription/{jdt}','JocdetronsController@inscription')->name('jdt.inscription');
            Route::post('/jdt/house/{jdt}','JocdetronsController@houseassign')->name('jdt.houseassign');
            Route::get('/jdt/map','JdtController@map')->name('jdt.map');
            Route::get('/jdt/{jdt}/turn/{turn}','TurnController@show')->name('jdt.turn');
            Route::post('/jdt/order/{id}','TurnController@orders')->name('jdt.userorders');
            Route::get('/jdt/turn/{id}','TurnController@NextPhase')->name('jdt.nextphase');
            Route::post('/jdt/raid/{id}','TurnController@raidorder')->name('jdt.raid');
            Route::post('/jdt/move/{id}','TurnController@moveorder')->name('jdt.move');
            Route::get('/jdt/combat/{id}','CombatController@show')->name('jdt.combat');
            Route::post('/jdt/combat/{id}','CombatController@update')->name('jdt.combat');
            Route::post('/jdt/westeros/recruitment/{id}','WesterosCardController@recruitment')->name('jdt.recruitment');
            Route::get('/jdt/westeros/supply/{id}','WesterosCardController@supply')->name('jdt.supply');
            Route::get('/jdt/westeros/shuffle/{id}','WesterosCardController@shuffle')->name('jdt.shuffle');
            Route::get('/jdt/westeros/lastsummer/{id}','WesterosCardController@lastsummer')->name('jdt.lastsummer');
            Route::post('/jdt/westeros/clashofkings/{id}','WesterosCardController@clashofkings')->name('jdt.clashofkings');
            Route::get('/jdt/westeros/gameofthrones/{id}','WesterosCardController@gameofthrones')->name('jdt.gameofthrones');
            Route::post('/jdt/westeros/wildattack/{id}','WesterosCardController@wildattack')->name('jdt.wildattack');
            Route::resource('/jdt','JocdetronsController');
    });

    

    //Control d'idiomes
    Route::get('lang/{lang}', function ($lang) {
        session(['lang' => $lang]);
        return \Redirect::back();
    })->where([
        'lang' => 'en|es|ca'
    ]);

});