<!DOCTYPE html>
<html lang="<?php echo e(app()->getLocale()); ?>">
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <!-- CSRF Token -->
    <meta name="csrf-token" content="<?php echo e(csrf_token()); ?>">

    <title><?php echo e(config('app.name', 'Laravel')); ?></title>

    <!-- Fonts -->
    <link href="https://fonts.googleapis.com/css?family=Cinzel|Raleway" rel="stylesheet" type="text/css">

    <!-- Styles -->
    <link href="<?php echo e(asset('css/app.css')); ?>" rel="stylesheet">
    <link href="/css/font-awesome.min.css" rel="stylesheet">
    <?php echo $__env->yieldPushContent('styles'); ?>
    <!-- Global site tag (gtag.js) - Google Analytics -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=UA-120303339-1"></script>
    <script>
        window.dataLayer = window.dataLayer || [];
        function gtag(){dataLayer.push(arguments);}
        gtag('js', new Date());
        gtag('config', 'UA-120303339-1');
    </script>
</head>
<body>
    <div id="app" class="d-flex flex-column">
        <nav class="navbar navbar-expand-md navbar-light navbar-laravel">
            <div class="container-fluid">
                <a class="navbar-brand" href="<?php echo e(url('/')); ?>">
                    <img class="brandimg" src="/img/logoh.png">
                </a>
                <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
                    <span class="navbar-toggler-icon"></span>
                </button>

                <div class="collapse navbar-collapse" id="navbarSupportedContent">
                    <!-- Left Side Of Navbar -->
                    <ul class="navbar-nav mr-auto">
                        <?php if(auth()->guard()->guest()): ?>
                            <li><a class="nav-link" href="<?php echo e(url('/')); ?>"><?php echo app('translator')->getFromJson('navigation.start'); ?></a></li>
                            <li><a class="nav-link" href="<?php echo e(route('jdt.index')); ?>"><?php echo app('translator')->getFromJson('navigation.games'); ?></a></li>
                            <li><a class="nav-link" href="<?php echo e(route('blog.index')); ?>"><?php echo app('translator')->getFromJson('navigation.spider'); ?></a></li>  
                        <?php else: ?>
                            <li><a class="nav-link" href="<?php echo e(route('home')); ?>"><?php echo app('translator')->getFromJson('navigation.start'); ?></a></li>
                            <li><a class="nav-link" href="<?php echo e(route('jdt.index')); ?>"><?php echo app('translator')->getFromJson('navigation.ogames'); ?></a></li>
                            <li><a class="nav-link" href="<?php echo e(route('message.index')); ?>"><?php echo app('translator')->getFromJson('navigation.crowns'); ?></a></li>
                            <?php if(auth()->user()->hasRoles(['admin'])): ?>
                                <li><a class="nav-link" href="<?php echo e(route('user.index')); ?>"><?php echo app('translator')->getFromJson('navigation.users'); ?></a></li>
                                <li><a class="nav-link" href="<?php echo e(route('post.index')); ?>"><?php echo app('translator')->getFromJson('navigation.posts'); ?></a></li>
                            <?php endif; ?>
                        <?php endif; ?>
                        <li><a class="nav-link" href="<?php echo e(route('rules')); ?>"><?php echo app('translator')->getFromJson('navigation.rules'); ?></a></li>
                    </ul>

                    <!-- Right Side Of Navbar -->
                    <ul class="navbar-nav ml-auto">
                        <!-- Authentication Links -->
                        <?php if(auth()->guard()->guest()): ?>
                            <li><a class="nav-link" href="<?php echo e(route('login')); ?>"><?php echo app('translator')->getFromJson('user.login'); ?></a></li>
                            <li><a class="nav-link" href="<?php echo e(route('register')); ?>"><?php echo app('translator')->getFromJson('user.register'); ?></a></li>
                        <?php else: ?>
                            <li class="nav-item dropdown">
                                <a id="navbarDropdown" class="nav-link dropdown-toggle" href="" role="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                    <?php echo e(Auth::user()->alias); ?> <span class="caret"></span>
                                </a>

                                <div class="dropdown-menu" aria-labelledby="navbarDropdown">
                                    <a class="dropdown-item" href="<?php echo e(route('user.show',Auth::user()->id)); ?>">
                                        <?php echo app('translator')->getFromJson('user.view'); ?>
                                    </a>
                                    <a class="dropdown-item" href="<?php echo e(route('user.edit',Auth::user()->id)); ?>">
                                        <?php echo app('translator')->getFromJson('user.edit'); ?>
                                    </a>
                                    <a class="dropdown-item" href="<?php echo e(route('logout')); ?>"
                                       onclick="event.preventDefault();
                                                     document.getElementById('logout-form').submit();">
                                        <?php echo app('translator')->getFromJson('user.logout'); ?>
                                    </a>

                                    <form id="logout-form" action="<?php echo e(route('logout')); ?>" method="POST" style="display: none;">
                                        <?php echo csrf_field(); ?>
                                    </form>
                                </div>
                            </li>
                        <?php endif; ?>
                    </ul>
                </div>
            </div>
        </nav>
        <main class="py-4">
            <?php echo $__env->yieldContent('content'); ?>
        </main>
        <footer class="d-flex align-items-center">
            <div class="legal d-flex align-items-center justify-content-center">
                <?php echo app('translator')->getFromJson('navigation.legal'); ?>
            </div>
            <div class="lang justify-content-center btn-group dropup">
                <button type="button" class="btn btn-veenders dropdown-toggle" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                    <?php echo e(App::getLocale()); ?>

                </button>
                <div class="dropdown-menu dropdown-lang dropdown-menu-right">
                    <a  class="dropdown-item" href="<?php echo e(url('lang', ['ca'])); ?>">Ca</a>
                    <a  class="dropdown-item" href="<?php echo e(url('lang', ['es'])); ?>">Es</a>
                    <a  class="dropdown-item" href="<?php echo e(url('lang', ['en'])); ?>">En</a>
                </div>
            </div>
        </footer>
    </div>

    <!-- Scripts -->
    <script src="<?php echo e(asset('js/app.js')); ?>"></script>
    <?php echo $__env->yieldPushContent('scripts'); ?>
</body>
</html>
